.. _examples:

*****************
Examples of usage
*****************

The folder **examples** contains scripts that show how Alpaca should be used
when implementing scripts with provenance tracking.

The example implements a simple analysis of electrophysiology data and utilizes
publicly available electrophysiology datasets. The following pages will guide you
through these examples step-by-step.

.. toctree::
    :maxdepth: 1

    examples/setup
    examples/simple
    examples/visualize
    examples/gephi
